.. include::
    ../README.rst

Contents:

.. toctree::
   :maxdepth: 2

   py_search 
   problems
   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

